@@ -25,7 +25,7 @@ from .errors import FireServiceRotaError, InvalidAuthError, ExpiredTokenError, I
 class FireServiceRota(object):
     """Class for communicating with the fireservicerota API."""
 
-    def __init__(self, base_url=None, username: str = None, password: str = None, token_info: dict = None):
+    def __init__(self, base_url = None, username: str = None, password: str = None, token_info: dict = None):
         """Init module"""
 
         self._base_url = base_url
@@ -49,7 +49,7 @@ class FireServiceRota(object):
             self._token_info = response
             _LOGGER.debug(f"Obtained tokens: access {self._token_info['access_token']}, "
                           f"refresh {self._token_info['refresh_token']}")
-            return response
+            return self._token_info
         except (KeyError, TypeError) as err:
             _LOGGER.debug(f"Error obtaining tokens: {err}")
             return False
@@ -68,10 +68,10 @@ class FireServiceRota(object):
                  params=str.encode(request_body), auth_request=True)
 
         try:
-            self._token_token = response
+            self._token_info = response
             _LOGGER.debug(f"Refreshed tokens: access {self._token_info['access_token']}, "
                           f"refresh {self._token_info['refresh_token']}")
-            return True
+            return self._token_info
         except (KeyError, TypeError) as err:
             _LOGGER.debug(f"Error refreshing tokens: {err}")
             return False
@@ -83,10 +83,15 @@ class FireServiceRota(object):
         self._user = self._request('GET', endpoint=FSR_ENDPOINT_USER, log_msg_action='get userid',
                  auth_request=False)
 
+        _LOGGER.debug(f"Userid data: {self._user}")
+
 
     def get_schedules(self):
         """Get user schedules."""
 
+        if not self._user:
+            self.get_userid()
+
         today = datetime.date.today()
         tomorrow = today + datetime.timedelta(days = 1)
         id =  self._user['memberships'][0]['id']
@@ -101,8 +106,12 @@ class FireServiceRota(object):
     def get_availability(self):
         """Get user availablity."""
 
+        if not self._user:
+            self.get_userid()
+
         today = datetime.date.today()
         tomorrow = today + datetime.timedelta(days = 1)
+
         id =  self._user['memberships'][0]['id']
         url = FSR_ENDPOINT_MEMBERSHIPS.format(id, today, tomorrow)
 
@@ -122,7 +131,11 @@ class FireServiceRota(object):
 
                return interval
 
-        return False
+#        return False
+
+
+    def update(self):
+        return self.get_availability()
 
 
     def _request(
@@ -213,7 +226,7 @@ class FireServiceRota(object):
         except (RequestException, json.decoder.JSONDecodeError):
             _LOGGER.error(
                 f"Error connecting to fireservicerota while attempting to {log_msg_action}. "
-                f"Possible connectivity outage."
+                f"{response.status_code}: {json_payload}"
             )
         return None
 
